
var setup = {
	
	init: function () {
		
		if (game.device.desktop) {
			game.scale.scaleMode = Phaser.ScaleManager.SHOW_ALL;
			game.scale.pageAlignHorizontally = true;
			game.scale.pageAlignVertically = true;
			document.getElementById("back").style.display = "block";
			isMobile = false;
		} else {
			game.scale.scaleMode = Phaser.ScaleManager.EXACT_FIT;
			game.scale.forceOrientation(false, true);
			game.scale.enterIncorrectOrientation.add(enterIncorrectOrientation);
			game.scale.leaveIncorrectOrientation.add(leaveIncorrectOrientation);
			isMobile = true;
		}
		
	},
	
	preload: function() {
		
		//---------------------------------------------------------------------------------
		//                              LOAD PRELOADER IMAGES
		//---------------------------------------------------------------------------------
		game.load.image("preloaderBG", "cubxer/preloader/preloaderBG.jpg");
		game.load.image("loadingBar", "cubxer/preloader/loadingBar.png");
		
	},
	
	create: function() {
		
		game.input.maxPointers = 1;
		game.state.start("preloader");
		
	}
	
}

function enterIncorrectOrientation() {
	document.getElementById("orientation").style.display = "block";
	game.paused = true;
}

function leaveIncorrectOrientation() {
	document.getElementById("orientation").style.display = "none";
	game.paused = false;
}

//---------------------------------------------------------------------------------
//                              DEFINE GAME VARIABLES
//---------------------------------------------------------------------------------
var soundsAreMuted = false;
var musicIsMuted = false;

var showFPS = false;

var gameWidth = 400;
var gameHeight = 640;

var centerX = gameWidth / 2;
var centerY = gameHeight / 2;

//-------------------------------------------------------------------------------------
//                              START GAME AND SET STATES
//-------------------------------------------------------------------------------------
var game = new Phaser.Game(gameWidth, gameHeight, Phaser.CANVAS, "game");

game.state.add("setup", setup);
game.state.add("preloader", preloader);
game.state.add("mobileState", mobileState);
game.state.add("menuState", menuState);
game.state.add("playState", playState);

game.state.start("setup");

//----------------------------------------------------------------------------------------
//                              DEFINE TWEEN BUTTON FUNCTION
//----------------------------------------------------------------------------------------
function tweenButton(x, y, image, action, sound, delay) {
	if (action === undefined) action = null;
	if (sound === undefined) sound = null;
	if (delay === undefined) delay = 0;
	if (delay == 0 && action != null) {
		var button = game.add.button(x, y, image, action);
	} else {
		var button = game.add.button(x, y, image);
	}
	button.action = action;
	button.delay = delay;
	button.anchor.setTo(0.5, 0.5);
	button.events.onInputOver.add(function() {
		game.add.tween(button.scale).to({x: 1.1,y: 1.1}, 40, Phaser.Easing.Linear.None).start();
	});
	button.events.onInputOut.add(function() {
		game.add.tween(button.scale).to({x: 1.0,y: 1.0}, 40, Phaser.Easing.Linear.None).start();
	});
	button.events.onInputDown.add(function() {
		if (!soundsAreMuted && sound != null) {
			sound.play();
		}; 
		game.add.tween(button.scale).to({x: .85,y: .85}, 40, Phaser.Easing.Linear.None).yoyo(true).start();
		if (button.delay < 0 && button.action != null) button.action();
	});
	button.events.onInputUp.add(function() {
		if (button.delay > 0 && button.action != null) game.time.events.add(Phaser.Timer.SECOND * button.delay, function() { button.action(); });
	});
	return button;
}

//----------------------------------------------------------------------------------------
//                              DEFINE NUMBER BLOCK FUNCTION
//----------------------------------------------------------------------------------------
function numberBlock(x, y, numberImage, numberOfDigits, spacing, startingCount) {
	if (spacing === undefined) spacing = 0;
	if (startingCount === undefined) startingCount = 0;
	var parentSprite = game.add.sprite(x, y);
	parentSprite.anchor.setTo(0.5, 0.5);
	var digitWidth = game.cache.getImage(numberImage).width / 10;
	var totalWidth = (digitWidth * numberOfDigits) + (spacing * (numberOfDigits - 1));
	var Xpos = (totalWidth / 2) - (digitWidth / 2);
	for (var i = 0; i < numberOfDigits; i++) {
		var childSprite = game.add.sprite(Xpos, 0, numberImage);
		childSprite.anchor.setTo(0.5, 0.5);
		parentSprite.addChild(childSprite);
		Xpos -= (digitWidth + spacing);
	}
	parentSprite.set = function(value) {
		parentSprite.value = value;
		for (var i = 0; i < numberOfDigits; i++) {
			parentSprite.children[i].frame = value - Math.floor(value / 10) * 10;
			value = Math.floor(value / 10);
		}
	}
	parentSprite.set(startingCount);
	return parentSprite;
}


//----------------------------------------------------------------------------
//                              LOAD STORED DATA
//----------------------------------------------------------------------------
try {
	if (localStorage.getItem("playLevel")) {
		playLevel = parseInt(localStorage.getItem("playLevel"), 10);
		score = parseInt(localStorage.getItem("score"), 10);
		highscore = parseInt(localStorage.getItem("highscore"), 10);
	} else {
		playLevel = 0;
		score = 0;
		highscore = 0;
		saveData();
	}
} catch(e) {
	playLevel = 0;
	score = 0;
	highscore = 0;
}

//----------------------------------------------------------------------------
//                              SAVE STORED DATA
//----------------------------------------------------------------------------
function saveData() {
	try {
		localStorage.setItem("playLevel", playLevel);
		localStorage.setItem("score", score);
		localStorage.setItem("highscore", highscore);
	} catch(e) {
		//
	}
}